import { Image, Text, View } from "@tarojs/components"
import { memo, useMemo, useState } from "react"
import styles  from './index.module.scss'
import classnames from "classnames";
import { formatDateTime, formatImgUrl } from "@/common/fotmat";
import { ORDER_STATUS, PAYMENT_METHOD, PAYMENT_METHOD_PARAM } from "@/common/enum";

type List = {
    status: string,
    time: string,
    tag: string,
    desc: string
}

type Param = {
    onRefresh?: () => void,
    orderInfo?: {
        logistics_details:List[], //订单状态列表
        payment_method: 0|PAYMENT_METHOD_PARAM, //支付方式
        status: number //订单状态
    }
}



export default memo(({orderInfo = {logistics_details: [],payment_method: 0, status: 0}, onRefresh}:Param) => {
    
    const [showMore, setShowMore] = useState(false)
    const changeMore = () => {
        setShowMore(() => !showMore)
    }
    const dataList = useMemo(() => {
        return orderInfo?.logistics_details?.reverse()||[]
    }, [orderInfo])

    //订单状态枚举
    const {SaleorderstatusWaitingPrePayment} = ORDER_STATUS

    //支付方式枚举
    const {
        PaymentMethodAccountPeriod,
        PaymentMethodCashOnDelivery,
    } = PAYMENT_METHOD

    //倒计时
    const count_down = useMemo(() => {
        
    }, [orderInfo])

    return (
        <>
            {(dataList?.length > 0)&&<View className={styles.order_flow_state}>
                <View className={classnames(styles.order_status_list, showMore&&styles.order_status_list_show)}>
                    {dataList.map((item, index) => <View className={styles.order_status_item}>
                        {(dataList.length > 1)&&<View className={classnames(styles.order_status_tail, (index == 0)&&styles.order_status_tail_end)}></View>}
                        {(dataList.length != (index + 1))&&<View className={styles.order_status_line}></View>}
                        <View className={styles.order_status_content}>
                            <View className={classnames(styles.order_status_title, (index == 0)&&styles.order_status_select)}>{item.status}</View>
                            <View className={classnames(styles.order_status_time, (index == 0)&&styles.order_status_select)}>{formatDateTime(item.time)}</View>
                            {/* <View className={classnames(styles.order_status_tag, (index == 0)&&styles.order_status_tag_select)}>{item.tag}</View> */}
                        </View>
                        <Text className={classnames(styles.order_status_des, (index == 0)&&styles.order_status_des_select)}>{item.desc}</Text>
                        {(orderInfo.status == SaleorderstatusWaitingPrePayment.value)&&<View className={styles.pay_time}>
                            剩<Text>23:58:55</Text>支付关闭，订单自动取消
                        </View>}
                    </View>)}
                </View>
                {(dataList.length > 2) && <View className={styles.more} onClick={() => changeMore()}>
                    <Text>{showMore&&'收起详情'||'点击查看详情'}</Text>
                    <Text className={classnames('iconfont icon-a-moreback', styles.miconfonts, showMore&&styles.open_miconfonts)}></Text>
                </View>}
                <View className={styles.image_tag}>
                    {(orderInfo.payment_method == PaymentMethodCashOnDelivery.value)&&<Image mode="aspectFit" src={formatImgUrl('/mall/order_pay_status.png')} className={styles.image}/>}
                    {(orderInfo.payment_method == PaymentMethodAccountPeriod.value)&&<Image mode="aspectFit" src={formatImgUrl('/mall/order_pay_status_7day.png')} className={styles.image}/>}
                </View>
                <View className={styles.refresh} onClick={onRefresh}>
                    <Text className={classnames(styles.mconfont, 'iconfont icon-xianxiahuikuan')}></Text>
                    <Text className={classnames(styles.refresh_text)}>刷新</Text>
                </View>
            </View>}
        </>
    )
})